@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 2543 2009-11-11 06:55:44Z fishbone $
+ * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 2582 2009-11-21 05:07:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -174,7 +174,7 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$this->tmpl->addVar("_widget", "content_type", $contentTypeStr);		// コンテンツ種別
 		
 		// 管理用URL設定
-		$adminUrl = $this->gEnv->getDefaultAdminUrl() . '?page=' . $this->pageId . '&sub=' . $this->pageSubId;
+		$adminUrl = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_DEF_PAGE_ID . '=' . $this->pageId . '&' . M3_REQUEST_PARAM_DEF_PAGE_SUB_ID . '=' . $this->pageSubId;
 		$this->tmpl->addVar("_widget", "admin_url", $this->getUrl($adminUrl));
 		
 		// ウィジェットIDのリスト
