@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainWidgetContainer.php 2567 2009-11-18 11:04:48Z fishbone $
+ * @version    SVN: $Id: blog_mainWidgetContainer.php 2775 2010-01-13 06:54:35Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -389,14 +389,14 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 			$iconUrl = $this->gEnv->getRootUrl() . self::NEW_ICON_FILE;		// 新規アイコン
 			$iconTitle = '新規';
 			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-			$buttonList .= '<span style="line-height:0;"><a href="#" onclick="editEntry(0);">' . $editImg . '</a><span>';
+			$buttonList .= '<span style="line-height:0;"><a href="#" onclick="editEntry(0);">' . $editImg . '</a></span>';
 			
 			// 設定画面表示ボタン
 			/*
 			$iconUrl = $this->gEnv->getRootUrl() . self::CONFIG_ICON_FILE;		// 設定アイコン
 			$iconTitle = 'ブログ設定';
 			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-			$buttonList .= '<span style="line-height:0;"><a href="#" onclick="showConfig();">' . $editImg . '</a><span>';
+			$buttonList .= '<span style="line-height:0;"><a href="#" onclick="showConfig();">' . $editImg . '</a></span>';
 			*/
 			
 			$this->tmpl->setAttribute('button_list', 'visibility', 'visible');
@@ -498,8 +498,8 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 			$iconUrl = $this->gEnv->getRootUrl() . self::EDIT_ICON_FILE;		// 編集アイコン
 			$iconTitle = '編集';
 			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-			$buttonList = '<span style="line-height:0;"><a href="#" onclick="editEntry(' . $fetchedRow['be_serial'] . ');">' . $editImg . '</a><span><br />';
-			//$buttonList = '<span style="line-height:0;"><a onclick="editEntry(' . $fetchedRow['be_serial'] . ');">' . $editImg . '</a><span><br />';
+			$buttonList = '<span style="line-height:0;"><a href="#" onclick="editEntry(' . $fetchedRow['be_serial'] . ');">' . $editImg . '</a></span><br />';
+			//$buttonList = '<span style="line-height:0;"><a onclick="editEntry(' . $fetchedRow['be_serial'] . ');">' . $editImg . '</a></span><br />';
 		}
 
 		$row = array(
