@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contactusWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
+ * @version    SVN: $Id: contactusWidgetContainer.php 2493 2009-10-31 06:16:06Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -132,66 +132,70 @@ class contactusWidgetContainer extends BaseWidgetContainer
 		$phone = $request->trimValueOf('item_phone');		// 電話番号
 		$body = $request->trimValueOf('item_body');		// 問い合わせ内容
 		if ($act == 'send'){		// お問い合わせメール送信
-			// 入力状況のチェック
-			if ($nameVisible && $nameRequired) $this->checkInput($name, 'お名前');
-			if ($nameKanaVisible && $nameKanaRequired) $this->checkInput($nameKana, 'お名前(カナ)');
-			if ($emailVisible){
-				if ($this->checkMailAddress($email, 'Eメール', !$emailRequired)){
-					if ($email != $email2) $this->setAppErrorMsg('Eメールアドレスに誤りがあります');
-				}
-			}
-			if ($companyVisible && $companyRequired) $this->checkInput($companyName, '会社名');
-			if ($zipcodeVisible && $zipcodeRequired) $this->checkInput($zipcode, '郵便番号');
-			if ($stateVisible && $stateRequired) $this->checkInput($this->state, '都道府県');
-			if ($addressVisible && $addressRequired) $this->checkInput($address, '住所');
-			if ($telVisible && $telRequired) $this->checkInput($phone, '電話番号');
-			if ($bodyVisible && $bodyRequired) $this->checkInput($body, 'お問い合わせ内容');
-
-			// エラーなしの場合はメール送信
-			if ($this->getMsgCount() == 0){
-				$this->setGuidanceMsg('送信完了しました');
-				
-				// メール送信設定のときはメールを送信
-				if ($sendMessage){
-					// メール本文の作成
-					$stateName = $this->db->getStateName('JPN', $this->langId, $this->state);
-					$mailBody = '';
-					if ($nameVisible)		$mailBody .= 'お名前　　　　　: ' . $name . "\n";
-					if ($nameKanaVisible)	$mailBody .= 'お名前（カナ）　: ' . $nameKana . "\n";
-					if ($emailVisible)		$mailBody .= 'Ｅメールアドレス: ' . $email . "\n";
-					if ($companyVisible)	$mailBody .= '会社名　　　　　: ' . $companyName . "\n";
-					if ($zipcodeVisible)	$mailBody .= '郵便番号　　　　: ' . $zipcode . "\n";
-					if ($stateVisible)		$mailBody .= '都道府県　　　　: ' . $stateName . "\n";
-					if ($addressVisible)	$mailBody .= '住所　　　　　　: ' . $address . "\n";
-					if ($telVisible)		$mailBody .= '電話番号　　　　: ' . $phone . "\n";
-					if ($bodyVisible)		$mailBody .= 'お問い合わせ内容: ' . $body . "\n";
-					
-					// 送信元、送信先
-					$fromAddress = $this->gEnv->getSiteEmail();	// 送信元はサイト情報のEメールアドレス
-					$toAddress = $this->gEnv->getSiteEmail();		// デフォルトのサイト向けEメールアドレス
-					if (!empty($emailReceiver)) $toAddress = $emailReceiver;		// 受信メールアドレスが設定されている場合
-					
-					// メールを送信
-					if (empty($toAddress)){
-						$this->gOpeLog->writeError(__METHOD__, 'メール送信に失敗しました。基本情報のEメールアドレスが設定されていません。', 1100, 'body=[' . $mailBody . ']');
-					} else {
-						$mailParam = array();
-						$mailParam['BODY'] = $mailBody;
-						$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, $email, '', self::CONTACTUS_FORM, $mailParam);
+			$postTicket = $request->trimValueOf('ticket');		// POST確認用
+			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
+			
+				// 入力状況のチェック
+				if ($nameVisible && $nameRequired) $this->checkInput($name, 'お名前');
+				if ($nameKanaVisible && $nameKanaRequired) $this->checkInput($nameKana, 'お名前(カナ)');
+				if ($emailVisible){
+					if ($this->checkMailAddress($email, 'Eメール', !$emailRequired)){
+						if ($email != $email2) $this->setAppErrorMsg('Eメールアドレスに誤りがあります');
 					}
 				}
+				if ($companyVisible && $companyRequired) $this->checkInput($companyName, '会社名');
+				if ($zipcodeVisible && $zipcodeRequired) $this->checkInput($zipcode, '郵便番号');
+				if ($stateVisible && $stateRequired) $this->checkInput($this->state, '都道府県');
+				if ($addressVisible && $addressRequired) $this->checkInput($address, '住所');
+				if ($telVisible && $telRequired) $this->checkInput($phone, '電話番号');
+				if ($bodyVisible && $bodyRequired) $this->checkInput($body, 'お問い合わせ内容');
 
-				$this->tmpl->addVar("show_name", "name_disabled", 'disabled');
-				$this->tmpl->addVar("show_name_kana", "name_kana_disabled", 'disabled');
-				$this->tmpl->addVar("show_email", "email_disabled", 'disabled');
-				$this->tmpl->addVar("show_email", "email2_disabled", 'disabled');
-				$this->tmpl->addVar("show_company_name", "company_name_disabled", 'disabled');
-				$this->tmpl->addVar("show_zipcode", "zipcode_disabled", 'disabled');
-				$this->tmpl->addVar("show_state", "state_disabled", 'disabled');
-				$this->tmpl->addVar("show_address", "address_disabled", 'disabled');
-				$this->tmpl->addVar("show_tel", "phone_disabled", 'disabled');
-				$this->tmpl->addVar("show_body", "body_disabled", 'disabled');
-				$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
+				// エラーなしの場合はメール送信
+				if ($this->getMsgCount() == 0){
+					$this->setGuidanceMsg('送信完了しました');
+				
+					// メール送信設定のときはメールを送信
+					if ($sendMessage){
+						// メール本文の作成
+						$stateName = $this->db->getStateName('JPN', $this->langId, $this->state);
+						$mailBody = '';
+						if ($nameVisible)		$mailBody .= 'お名前　　　　　: ' . $name . "\n";
+						if ($nameKanaVisible)	$mailBody .= 'お名前（カナ）　: ' . $nameKana . "\n";
+						if ($emailVisible)		$mailBody .= 'Ｅメールアドレス: ' . $email . "\n";
+						if ($companyVisible)	$mailBody .= '会社名　　　　　: ' . $companyName . "\n";
+						if ($zipcodeVisible)	$mailBody .= '郵便番号　　　　: ' . $zipcode . "\n";
+						if ($stateVisible)		$mailBody .= '都道府県　　　　: ' . $stateName . "\n";
+						if ($addressVisible)	$mailBody .= '住所　　　　　　: ' . $address . "\n";
+						if ($telVisible)		$mailBody .= '電話番号　　　　: ' . $phone . "\n";
+						if ($bodyVisible)		$mailBody .= 'お問い合わせ内容: ' . $body . "\n";
+					
+						// 送信元、送信先
+						$fromAddress = $this->gEnv->getSiteEmail();	// 送信元はサイト情報のEメールアドレス
+						$toAddress = $this->gEnv->getSiteEmail();		// デフォルトのサイト向けEメールアドレス
+						if (!empty($emailReceiver)) $toAddress = $emailReceiver;		// 受信メールアドレスが設定されている場合
+					
+						// メールを送信
+						if (empty($toAddress)){
+							$this->gOpeLog->writeError(__METHOD__, 'メール送信に失敗しました。基本情報のEメールアドレスが設定されていません。', 1100, 'body=[' . $mailBody . ']');
+						} else {
+							$mailParam = array();
+							$mailParam['BODY'] = $mailBody;
+							$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, $email, '', self::CONTACTUS_FORM, $mailParam);
+						}
+					}
+
+					$this->tmpl->addVar("show_name", "name_disabled", 'disabled');
+					$this->tmpl->addVar("show_name_kana", "name_kana_disabled", 'disabled');
+					$this->tmpl->addVar("show_email", "email_disabled", 'disabled');
+					$this->tmpl->addVar("show_email", "email2_disabled", 'disabled');
+					$this->tmpl->addVar("show_company_name", "company_name_disabled", 'disabled');
+					$this->tmpl->addVar("show_zipcode", "zipcode_disabled", 'disabled');
+					$this->tmpl->addVar("show_state", "state_disabled", 'disabled');
+					$this->tmpl->addVar("show_address", "address_disabled", 'disabled');
+					$this->tmpl->addVar("show_tel", "phone_disabled", 'disabled');
+					$this->tmpl->addVar("show_body", "body_disabled", 'disabled');
+					$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
+				}
 			}
 			$this->tmpl->addVar("show_name", "name", $name);
 			$this->tmpl->addVar("show_name_kana", "name_kana", $nameKana);
@@ -203,7 +207,14 @@ class contactusWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->addVar("show_tel", "phone", $phone);
 			$this->tmpl->addVar("show_body", "body", $body);
 			$this->tmpl->addVar("_widget", "send_button_label", '送信する');// 送信ボタンラベル
+			
+			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 		} else {
+			// ハッシュキー作成
+			$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
+			$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
+			$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
+			
 			// メール送信不可の場合はボタンを使用不可にする
 			if ($sendMessage){
 				$this->tmpl->addVar("_widget", "send_button_label", '送信する');// 送信ボタンラベル
