@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 2574 2009-11-20 04:57:25Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 2686 2009-12-15 07:58:30Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -32,6 +32,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
 	const ACTIVE_ICON_FILE = '/images/system/active.png';			// 公開中アイコン
 	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
+	const MSG_UPDATE_CONTENT = 'コンテンツを更新しました';			// コンテンツ更新メッセージ
 	
 	/**
 	 * コンストラクタ
@@ -218,6 +219,10 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					// シリアル番号更新
 					$this->serialNo = $newSerial;
 					$reloadData = true;		// データの再読み込み
+					
+					// コンテンツ更新情報をサーバへ登録
+					$ret = $this->registContentInfoBySerial($this->serialNo, true/*新規*/);
+					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
@@ -254,6 +259,10 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
+					
+					// コンテンツ更新情報をサーバへ登録
+					$ret = $this->registContentInfoBySerial($this->serialNo);
+					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
 				} else {
 					$this->setAppErrorMsg('データ更新に失敗しました');
 				}
@@ -394,13 +403,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			}
 		}
 		if ($act == 'addtomenu'){			// メニューに項目を追加
-			// このウィジェットがマップされているページサブIDを取得
-			$subPageId = $this->gPage->getPageSubIdByWidget($this->gEnv->getDefaultPageId(), $this->gEnv->getCurrentWidgetId());
-			$sub = '';
-			if (!empty($subPageId)) $sub = 'sub=' . $subPageId . '&';
-			
 			// URLの作成
-			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/' . $this->gEnv->getDefaultPageId() . '.php?' . $sub . 'contentid=' . $contentId;
+			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/' . $this->gEnv->getDefaultPageId() . '.php?contentid=' . $contentId;
 
 			// コンテンツ名を取得
 			$menutItemName = '';
@@ -585,5 +589,26 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		}
 		return $isActive;
 	}
+	/**
+	 * コンテンツ更新情報をサーバへ登録
+	 *
+	 * @param int $serial		コンテンツシリアル番号
+	 * @param bool $isNew		新規または更新
+	 * @return					なし
+	 */
+	function registContentInfoBySerial($serial, $isNew=false)
+	{
+		$ret = $this->db->getContentBySerial($serial, $row);		// コンテンツID取得
+		if ($ret){
+			$contentId = $row['cn_id'];		// コンテンツID
+			$contentTitle = $row['cn_name'];		// コンテンツタイトル
+			$contentLink = $url = $this->gEnv->getDefaultUrl() . '?contentid=' . $contentId;		// コンテンツリンク先
+			$contentDt = $row['cn_create_dt'];		// コンテンツ更新日時
+			
+			$ret = $this->gInstance->getConnectManager()->registUpdateInfo(''/*汎用コンテンツ*/, ''/*送信先はデフォルトURL*/, ''/*デフォルトウィジェットに送信*/, 
+								$this->gEnv->getCurrentWidgetId(), self::MSG_UPDATE_CONTENT, $contentTitle, $contentLink, $contentDt);
+		}
+		return $ret;
+	}
 }
 ?>
