@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_menuWidgetContainer.php 2547 2009-11-12 06:39:59Z fishbone $
+ * @version    SVN: $Id: admin_default_menuWidgetContainer.php 2572 2009-11-19 01:19:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -139,7 +139,7 @@ class admin_default_menuWidgetContainer extends BaseAdminWidgetContainer
 				// 画面定義更新
 				if ($ret && !empty($defSerial)){		// 画面作成から呼ばれている場合のみ更新
 					$newConfigId = $newParam->id;
-					$ret = $this->sysDb->updateWidgetConfigId($this->gEnv->getCurrentWidgetId(), $defSerial, $newConfigId, $name);
+					$ret = $this->sysDb->updateWidgetConfigId($this->gEnv->getCurrentWidgetId(), $defSerial, $newConfigId, $name, $this->menuId);
 				}
 				
 				if ($ret){
@@ -165,6 +165,8 @@ class admin_default_menuWidgetContainer extends BaseAdminWidgetContainer
 					if ($id == $this->configId){
 						// ウィジェットオブジェクト更新。更新値のみ再設定。
 						if (!empty($defConfigId) && !empty($defSerial)){		// 設定再選択不可の場合
+							// 取得値で更新
+							$this->menuId = $targetObj->menuId;		// メニューID
 						} else {			// 新規で既存設定の更新
 							$targetObj->menuId	= $this->menuId;		// メニューID
 							$targetObj->isHierMenu = $isHierMenu;		// 階層化メニューを使用するかどうか
@@ -178,7 +180,7 @@ class admin_default_menuWidgetContainer extends BaseAdminWidgetContainer
 				}
 				// 画面定義更新
 				if (!empty($defSerial)){		// 画面作成から呼ばれている場合のみ更新
-					if ($ret) $ret = $this->sysDb->updateWidgetConfigId($this->gEnv->getCurrentWidgetId(), $defSerial, $this->configId, $targetObj->name);
+					if ($ret) $ret = $this->sysDb->updateWidgetConfigId($this->gEnv->getCurrentWidgetId(), $defSerial, $this->configId, $targetObj->name, $this->menuId);
 				}
 
 				if ($ret){
