@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 2547 2009-11-12 06:39:59Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 2553 2009-11-14 11:32:06Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -166,10 +166,24 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						}
 						break;
 					case 2:			// テキストのとき
+						$treeHtml .= '<li><span>' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
+						break;
 					case 3:			// セパレータのとき
+						$treeHtml .= '<li><span class="separator">' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
 						break;
 				}
 				$index++;		// インデックス番号更新
+				
+				if ($this->templateType == 0){			// Joomla!v1.0のとき
+					$itemRow = array(
+						'link_url' => $this->convertUrlToHtmlEntity($linkUrl),		// リンク
+						'name' => $this->convertToDispString($name),			// タイトル
+						'attr' => $attr,			// liタグ追加属性
+						'option' => $option			// Aタグ追加属性
+					);
+					$this->tmpl->addVars('itemlist', $itemRow);
+					$this->tmpl->parseTemplate('itemlist', 'a');
+				}
 			}
 		}
 		return $treeHtml;
